@@ -23,6 +23,7 @@
 
 from __future__ import unicode_literals
 
+import ast
 import difflib
 import opcode
 import pprint
@@ -35,12 +36,7 @@ except NameError:
     basestring = str
 
 
-__version__ = '0.1.3'
-
-
-class DisassembleSyntaxError(SyntaxError):
-
-    """Raised if syntax error is detected while disassembling."""
+__version__ = '0.2'
 
 
 def diff_bytecode_of_files(filename_a, filename_b):
@@ -58,6 +54,10 @@ def diff_bytecode_of_files(filename_a, filename_b):
 def diff_bytecode(source_a, source_b,
                   filename_a='', filename_b=''):
     """Return diff of the bytecode of the two sources."""
+    # Compare AST first to avoid some false positives.
+    if dump_ast(source_a, filename_a) == dump_ast(source_b, filename_b):
+        return ''
+
     bytecode_a = disassemble(source_a, filename_a)
     bytecode_b = disassemble(source_b, filename_b)
 
@@ -68,18 +68,17 @@ def diff_bytecode(source_a, source_b,
         filename_b))
 
 
-def disassemble(source, filename=''):
+def disassemble(source, filename=None):
     """Return dictionary of disassembly."""
-    try:
-        return tree(compile(source, '<string>', 'exec', dont_inherit=True))
-    except SyntaxError as syntax_error:
-        exception = DisassembleSyntaxError()
-        exception.filename = filename
-        exception.msg = syntax_error.msg
-        exception.text = syntax_error.text
-        exception.lineno = syntax_error.lineno
-        exception.offset = syntax_error.offset
-        raise exception
+    return tree(compile(source,
+                        filename or '<string>',
+                        'exec',
+                        dont_inherit=True))
+
+
+def dump_ast(source, filename=None):
+    """Return AST."""
+    return ast.dump(ast.parse(source, filename or '<string>', 'exec'))
 
 
 def tree(code):
@@ -165,7 +164,7 @@ def main(argv, standard_out, standard_error):
         diff = diff_bytecode_of_files(args.files[0], args.files[1])
         if diff:
             standard_out.write(diff + '\n')
-    except DisassembleSyntaxError as exception:
+    except SyntaxError as exception:
         standard_error.write(
             '{0}:{1} invalid syntax\n'.format(
                 exception.filename,
